Index: cc/tiles/tile_manager.cc |
diff --git a/cc/tiles/tile_manager.cc b/cc/tiles/tile_manager.cc |
index 23d2eca12bc23f35ee754226ba18be01066341ca..545866e3f3e52b048b85b03a19120c5ab06cee52 100644 |
--- a/cc/tiles/tile_manager.cc |
+++ b/cc/tiles/tile_manager.cc |
@@ -1045,9 +1045,10 @@ TileManager::MemoryUsage::MemoryUsage(size_t memory_bytes, |
TileManager::MemoryUsage TileManager::MemoryUsage::FromConfig( |
const gfx::Size& size, |
ResourceFormat format) { |
// We can use UncheckedMemorySizeBytes here since this is used with a tile |
// size which is determined by the compositor (it's at most max texture size). |
- return MemoryUsage(Resource::UncheckedMemorySizeBytes(size, format), 1); |
+ return MemoryUsage(ResourceUtil::UncheckedSizeInBytes<size_t>(size, format), |
+ 1); |
} |
// static |
@@ -1045,9 +1045,10 @@ TileManager::MemoryUsage::MemoryUsage(size_t memory_bytes, |
const gfx::Size& size, |
ResourceFormat format) { |
- // We can use UncheckedMemorySizeBytes here since this is used with a tile |
+ // We can use UncheckedSizeInBytes here since this is used with a tile |
// size which is determined by the compositor (it's at most max texture size). |